summaryrefslogtreecommitdiffstats
path: root/pyuic3/form.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:18:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:18:57 -0600
commit752274609034af8c68c46d19bed586ea6ae348b8 (patch)
treee8e76ca1acfa09d45f399a88cb3ada51992ae574 /pyuic3/form.cpp
parentd2b09f66d0c8c8c26ec613b96d7c248e78a5c52f (diff)
downloadpytqt-752274609034af8c68c46d19bed586ea6ae348b8.tar.gz
pytqt-752274609034af8c68c46d19bed586ea6ae348b8.zip
Fix retquire
Diffstat (limited to 'pyuic3/form.cpp')
-rw-r--r--pyuic3/form.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/pyuic3/form.cpp b/pyuic3/form.cpp
index 31785ac..427aa66 100644
--- a/pyuic3/form.cpp
+++ b/pyuic3/form.cpp
@@ -118,7 +118,7 @@ void Uic::createFormImpl( const TQDomElement &e )
return;
TQString objName = getObjectName( e );
// generate local and local includes retquired
TQStringList globalIncludes;
TQStringList::Iterator it;
TQStringList sqlClasses;
@@ -319,8 +319,8 @@ void Uic::createFormImpl( const TQDomElement &e )
out << endl;
- // find out what images are retquired
- TQStringList retquiredImages;
+ // find out what images are required
+ TQStringList requiredImages;
static const char *imgTags[] = { "pixmap", "iconset", 0 };
for ( i = 0; imgTags[i] != 0; i++ ) {
nl = e.parentNode().toElement().elementsByTagName( imgTags[i] );
@@ -329,7 +329,7 @@ void Uic::createFormImpl( const TQDomElement &e )
while ( nn.parentNode() != e.parentNode() )
nn = nn.parentNode();
if ( nn.nodeName() != "customwidgets" )
- retquiredImages += nl.item(j).firstChild().toText().data();
+ requiredImages += nl.item(j).firstChild().toText().data();
}
}
@@ -345,7 +345,7 @@ void Uic::createFormImpl( const TQDomElement &e )
nl = n.elementsByTagName( "image" );
for ( i = 0; i < (int) nl.length(); i++ ) {
TQString img = registerObject( nl.item(i).toElement().attribute( "name" ) );
- if ( !retquiredImages.contains( img ) )
+ if ( !requiredImages.contains( img ) )
continue;
TQDomElement tmp = nl.item(i).firstChild().toElement();
if ( tmp.tagName() != "data" )
@@ -508,7 +508,7 @@ void Uic::createFormImpl( const TQDomElement &e )
out << endl;
- // create all children, some forms have special retquirements
+ // create all children, some forms have special requirements
if ( objClass == "TQWizard" ) {
for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
@@ -723,7 +723,7 @@ void Uic::createFormImpl( const TQDomElement &e )
--indent;
}
// handle application events if retquired
bool needFontEventHandler = FALSE;
bool needSqlTableEventHandler = FALSE;
bool needSqlDataBrowserEventHandler = FALSE;
@@ -118,7 +118,7 @@ void Uic::createFormImpl( const TQDomElement &e )
return;
TQString objName = getObjectName( e );
- // generate local and local includes retquired
+ // generate local and local includes required
TQStringList globalIncludes;
TQStringList::Iterator it;
@@ -723,7 +723,7 @@ void Uic::createFormImpl( const TQDomElement &e )
}
- // handle application events if retquired
+ // handle application events if required
bool needFontEventHandler = FALSE;
bool needSqlTableEventHandler = FALSE;